/*
 * Copyright (C) 2005-2012 Alfresco Software Limited.
 *
 * This file is part of Alfresco
 *
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 */
package org.alfresco.bm.process.share;

import org.alfresco.bm.event.Event;
import org.alfresco.bm.event.EventResult;
import org.alfresco.bm.process.share.entity.ShareEventData;
import org.alfresco.bm.user.UserDataService;
import org.alfresco.po.share.SharePage;
import org.alfresco.webdrone.WebDrone;

/**
 * Terminates the {@link WebDrone} session</br>
 * 
 * <h1>Input</h1>
 * 
 * {@link ShareEventData} entity that contains the {@link WebDrone}.
 * 
 * <h1>Actions</h1>
 * Invokes {@link WebDrone} quit method.
 * 
 * <h1>Output</h1>
 * {@link #EVENT_NAME_WEBDRONE_CLOSED}: No data
 *
 * @author Michael Suzuki
 * @since 1.0
 */
public class WebDroneCloseEventProcess extends AbstractShareEventProcessor
{
    private static final String EVENT_NAME_WEBDRONE_CLOSED = "share.webDroneClosed";
    
    public WebDroneCloseEventProcess(UserDataService userDataService)
    {
        super(userDataService, EVENT_NAME_WEBDRONE_CLOSED);
    }

    @Override
    public EventResult processEvent(Event event, ShareEventData eventData) throws Exception
    {
        WebDrone drone = null;
        SharePage page = eventData.getSharePage();
        if (null != page)
        {
            drone = eventData.getWebDrone();
        }
        String sessionId = event.getSessionId();
        closeWebDrone(drone, sessionId);
        Event nextEvent = new Event(eventNameActionComplete, null);

        String pageStr;
        try
        {
            pageStr = "" + page;
        }
        catch (Exception e)
        {
            // It happens
            pageStr = "[SharePage.toString() failed: " + e.getMessage() + "]";
        }
        
        return new EventResult(
                "WebDrone closed on page: " + pageStr,
                nextEvent);
    }
}
