/*
 * Copyright (C) 2005-2013 Alfresco Software Limited.
 *
 * This file is part of Alfresco
 *
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 */
package org.alfresco.bm.process.share.entity;

/**
 * Extension of {@link ShareEventData} that holds data for searching
 * <ul>
 *     <li>searchTerm</li>
 * </ul>
 * 
 * @author Derek Hulley
 * @since 1.1
 */
public class ShareSearchEventData extends ShareEventData 
{
    private final String searchTerm;

    /**
     * Constructor.
     * 
     * @param copyFrom          existing data to copy values from
     * @param searchTerm        the search term
     */
    public ShareSearchEventData(ShareEventData copyFrom, String searchTerm)
    {
        super(copyFrom);
        
        if (searchTerm == null)
        {
            throw new IllegalArgumentException("'searchTerm' may not be null.");
        }
        
        this.searchTerm = searchTerm;
    }

    public String getSearchTerm()
    {
        return searchTerm;
    }
}
