/*
 * Copyright (C) 2005-2013 Alfresco Software Limited.
 *
 * This file is part of Alfresco
 *
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 */
package org.alfresco.bm.process.share.entity;

import org.alfresco.po.share.ShareLink;

/**
 * Extension of {@link ShareEventData} that holds extra information to search for sites.
 * <ul>
 *     <li>siteLink</li>
 * </ul>
 * 
 * @author Derek Hulley
 * @since 1.0
 */
public class ShareSelectSiteEventData extends ShareEventData 
{
    private final ShareLink siteLink;

    /**
     * Constructor.
     * 
     * @param copyFrom          existing data to copy values from
     * @param siteLink          the link to the site
     */
    public ShareSelectSiteEventData(ShareEventData copyFrom, ShareLink siteLink)
    {
        super(copyFrom);
        
        if (siteLink == null)
        {
            throw new IllegalArgumentException("'siteLink' may not be null.");
        }
        
        this.siteLink = siteLink;
    }
    
    /**
     * @throws UnsupportedOperationException always
     */
    @Override
    public void setSiteName(String siteName)
    {
        throw new UnsupportedOperationException("The value 'siteName' cannot be changed.  The superclass method is deprecated.");
    }

    public ShareLink getSiteLink()
    {
        return siteLink;
    }
}
