/*
 * Copyright (C) 2005-2012 Alfresco Software Limited.
 *
 * This file is part of Alfresco
 *
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 */
package org.alfresco.bm.process.share.site;

import org.alfresco.bm.event.Event;
import org.alfresco.bm.event.EventResult;
import org.alfresco.bm.process.share.AbstractShareEventProcessor;
import org.alfresco.bm.process.share.entity.ShareEventData;
import org.alfresco.bm.user.UserDataService;
import org.alfresco.po.share.site.document.DocumentDetailsPage;
import org.alfresco.po.share.site.document.DocumentEditOfflinePage;

/**
 * Click <i>Edit Offline</i>.
 *  
 * <h1>Input</h1> 
 * 
 * {@link DocumentDetailsPage} showing the file details with <i>Upload New Version</i> on display.
 * 
 * <h1>Actions</h1>
 * 
 * Clicks the Edit Offline link, which will get the browser to download the document
 * to the download location.
 * 
 * <h1>Output</h1>
 * 
 * {@link #EVENT_NAME_EDIT_OFFLINE_COMPLETE}: {@link DocumentEditOfflinePage} in {@link ShareEventData}<br/>
 * 
 * @author Derek Hulley
 * @since 1.0
 */
public class EditOfflineEventProcess extends AbstractShareEventProcessor
{
    public static final String EVENT_NAME_EDIT_OFFLINE_COMPLETE = "share.docDetails.editOffline.complete";
    
    /**
     * @param userDataService           service to provide user data
     */
    public EditOfflineEventProcess(UserDataService userDataService)
    {
        super(userDataService,EVENT_NAME_EDIT_OFFLINE_COMPLETE);
    }

    @Override
    public EventResult processEvent(Event event, ShareEventData eventData) throws Exception
    {
        DocumentDetailsPage docDetailsPage = (DocumentDetailsPage) eventData.getSharePage();
        if (docDetailsPage instanceof DocumentEditOfflinePage)
        {
            throw new RuntimeException("Unable to 'Edit Offline' because we are already.");
        }
        // Get the title
        String title = docDetailsPage.getDocumentTitle();
        
        // Click the link
        DocumentEditOfflinePage editOfflinePage = docDetailsPage.selectEditOffLine(null).render();
        eventData.setSharePage(editOfflinePage);
        Event nextEvent = new Event(eventNameActionComplete, eventData);
        EventResult result = new EventResult(
                "Clicked 'Edit Offline': " + title,
                nextEvent);
        return result;
    }
}
