/*
 * Copyright (C) 2005-2012 Alfresco Software Limited.
 *
 * This file is part of Alfresco
 *
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 */
package org.alfresco.bm.process.share.site;

import org.alfresco.bm.event.Event;
import org.alfresco.bm.event.EventResult;
import org.alfresco.bm.process.share.AbstractShareEventProcessor;
import org.alfresco.bm.process.share.entity.ShareEventData;
import org.alfresco.bm.user.UserDataService;
import org.alfresco.po.share.site.CustomizeSitePage;
import org.alfresco.po.share.site.SiteDashboardPage;

/**
 * Navigate to Alfresco share site customise page, mimics the action of selecting the customise site button from
 * the site page.
 *  
 * <h1>Input</h1> 
 * 
 * {@link ShareEventData} containing:<br/>
 * {@link SiteDashboardPage}.
 * 
 * <h1>Actions</h1>
 * 
 * Selects the customize site navigation button
 * 
 * <h1>Output</h1>
 * 
 * {@link #EVENT_NAME_SELECT_CUSTOMISE_SITE}: {@link SiteDashboardPage} in {@link ShareEventData}<br/>
 * 
 * @author Michael Suzuki
 * 
 * @since 1.4.2
 */
public class SelectCustomizeSiteEventProcess extends AbstractShareEventProcessor
{
    public static final String EVENT_NAME_SELECT_CUSTOMISE_SITE = "share.site.customize.selected";

    public SelectCustomizeSiteEventProcess(UserDataService userDataService)
    {
        super(userDataService,EVENT_NAME_SELECT_CUSTOMISE_SITE);
    }
    
    /**
     * Process which looks for the customize site link on the site dashboard page and clicks it
     * to redirect user to the customize site page.
     * 
     * @param eventData {@link Event} event information
     * @return {@link EventResult} result of the process
     */
    @Override
    public EventResult processEvent(Event event, ShareEventData eventData) throws Exception
    {
        ShareEventData pagingEventData = (ShareEventData) eventData;
        SiteDashboardPage siteDashboardPage = (SiteDashboardPage) pagingEventData.getSharePage();
        String siteName = siteDashboardPage.getPageTitle();
        CustomizeSitePage page = siteDashboardPage.getSiteNav().selectCustomizeSite().render();
        
        eventData.setSharePage(page);
        Event nextEvent = new Event(eventNameActionComplete, eventData);
        EventResult result = new EventResult(
                "Clicked customise on site " + siteName ,
                nextEvent);
        return result;
        
    }
}
