/*
 * Copyright (C) 2005-2012 Alfresco Software Limited.
 *
 * This file is part of Alfresco
 *
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 */
package org.alfresco.bm.process.share.site;

import org.alfresco.bm.event.Event;
import org.alfresco.bm.event.EventResult;
import org.alfresco.bm.process.share.AbstractShareEventProcessor;
import org.alfresco.bm.process.share.entity.ShareEventData;
import org.alfresco.bm.process.share.entity.SharePagingEventData;
import org.alfresco.bm.user.UserDataService;
import org.alfresco.po.share.site.document.DocumentDetailsPage;
import org.alfresco.po.share.site.document.DocumentLibraryPage;

/**
 * Selects the next or previous page on the document library.
 *  
 * <h1>Input</h1>
 *  
 * {@link SharePagingEventData} containing a {@link DocumentLibraryPage}.
 * 
 * <h1>Actions</h1>
 * 
 * Selects the next page, which must be present.
 * 
 * <h1>Output</h1>
 * 
 * {@link #EVENT_NAME_PAGE_COMPLETE}: {@link DocumentDetailsPage} in {@link ShareEventData}<br/>
 * 
 * @author Derek Hulley
 * @since 1.0
 */
public class SelectDocLibPageEventProcess extends AbstractShareEventProcessor
{
    public static final String EVENT_NAME_PAGE_COMPLETE = "share.doclib.page.complete";

    public SelectDocLibPageEventProcess(UserDataService userDataService)
    {
        super(userDataService, EVENT_NAME_PAGE_COMPLETE);
    }
    
    /**
     * Selects the next page
     */
    @Override
    public EventResult processEvent(Event event, ShareEventData eventData) throws Exception
    {
        SharePagingEventData pagingEventData = (SharePagingEventData) eventData;
        DocumentLibraryPage doclibPage = (DocumentLibraryPage) eventData.getSharePage();

        boolean forward = pagingEventData.isForward();
        if (forward)
        {
            doclibPage.selectNextPage();
        }
        else
        {
            doclibPage.selectPreviousPage();
        }
        doclibPage = doclibPage.render();
        
        eventData.setSharePage(doclibPage);
        Event nextEvent = new Event(eventNameActionComplete, eventData);
        EventResult result = new EventResult(
                "Clicked doclib for " + (forward ? "next" : "previous") + " page" + eventData,
                nextEvent);
        return result;
    }
}
