/*
 * Copyright (C) 2005-2013 Alfresco Software Limited.
 *
 * This file is part of Alfresco
 *
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 */
package org.alfresco.bm.process.share.site;

import org.alfresco.bm.event.Event;
import org.alfresco.bm.event.EventResult;
import org.alfresco.bm.process.share.AbstractShareEventProcessor;
import org.alfresco.bm.process.share.entity.ShareEventData;
import org.alfresco.bm.user.UserDataService;
import org.alfresco.po.share.site.NewFolderPage;
import org.alfresco.po.share.site.document.DocumentLibraryPage;

/**
 * Select <i>New Folder</i> link on the document library page.
 *  
 * <h1>Input</h1>
 *  
 * {@link ShareEventData} containing {@link DocumentLibraryPage}.
 * 
 * <h1>Actions</h1>
 * 
 * Clicks the <i>New Folder</i> link.
 * 
 * <h1>Output</h1>
 * 
 * {@link #EVENT_NAME_SELECT_NEW_FOLDER_COMPLETE}: {@link NewFolderPage} in {@link ShareEventData}<br/>
 * 
 * @author Derek Hulley
 * @since 1.0
 */
public class SelectNewFolderEventProcess extends AbstractShareEventProcessor
{
    public static final String EVENT_NAME_SELECT_NEW_FOLDER_COMPLETE = "share.doclib.selectNewFolder.complete";

    public SelectNewFolderEventProcess(UserDataService userDataService)
    {
        super(userDataService,EVENT_NAME_SELECT_NEW_FOLDER_COMPLETE);
    }
    
    /**
     * Process which selects the <i>New Folder</i>.
     * 
     * @param eventData {@link Event} event information
     * @return {@link EventResult} result of the process
     */
    @Override
    public EventResult processEvent(Event event, ShareEventData eventData) throws Exception
    {
        DocumentLibraryPage docPage = (DocumentLibraryPage) eventData.getSharePage();
        NewFolderPage newFolderPage = docPage.getNavigation().selectCreateNewFolder().render();
        eventData.setSharePage(newFolderPage);
        Event nextEvent = new Event(eventNameActionComplete, eventData);
        EventResult result = new EventResult(
                "'New Folder' selected: " + eventData,
                nextEvent);
        return result;
    }
}
