/*
 * Copyright (C) 2005-2013 Alfresco Software Limited.
 *
 * This file is part of Alfresco
 *
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 */
package org.alfresco.bm.process.share.soak;

import org.springframework.beans.factory.BeanNameAware;
import org.springframework.beans.factory.InitializingBean;

/**
 * Abstract implementation that handles scenario registration
 * 
 * @author Derek Hulley
 * @since 1.0
 */
public abstract class AbstractShareScenario implements ShareScenario, BeanNameAware, InitializingBean
{
    private final ShareScenarioRegistry registry;
    private final double weight;
    private String scenarioName;
    private String beanName;
    
    /**
     * @param registry              registry with which this instance will be registered
     * @param weight                the weight relative to other scenarios registered in the registry
     */
    public AbstractShareScenario(ShareScenarioRegistry registry, double weight)
    {
        this.registry = registry;
        this.weight = weight;
    }

    /**
     * Used by framework.  Do not use.
     * @see #setScenarioName(String) 
     */
    @Override
    public void setBeanName(String name)
    {
        this.beanName = name;
    }

    /**
     * Explicitly set the scenario name (if the bean name won't do).
     */
    public void setScenarioName(String scenarioName)
    {
        this.scenarioName = scenarioName;
    }

    @Override
    public void afterPropertiesSet() throws Exception
    {
        if (scenarioName != null)
        {
            registry.register(scenarioName, this, weight);
        }
        else if (beanName != null)
        {
            registry.register(beanName, this, weight);
        }
        else
        {
            throw new IllegalStateException("No session name provided.");
        }
    }
}
