/*
 * Copyright (C) 2005-2013 Alfresco Software Limited.
 *
 * This file is part of Alfresco
 *
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 */
package org.alfresco.bm.process.share.soak;

import java.util.Collections;
import java.util.List;

import org.alfresco.bm.event.Event;
import org.alfresco.bm.process.share.entity.ShareDownloadEventData;
import org.alfresco.bm.process.share.entity.ShareEventData;
import org.alfresco.po.share.SharePage;
import org.alfresco.po.share.site.document.DocumentDetailsPage;
import org.alfresco.po.share.site.document.DocumentEditOfflinePage;

/**
 * Scenario around document <i>Edit Offline</i>
 * <p/>
 * The following page is executed.  <b>*</b> indicates a possible start location.
 * <ul>
 *   <li><b>*  1. {@link DocumentDetailsPage} (with <i>Upload New Version</i> link):</b> Selects <i>Edit Offline</i></li>
 *   <li><b>   2. {@link DocumentEditOfflinePage}: </b> END</li>
 * </ul>
 * 
 * @author Derek Hulley
 * @since 1.0
 */
public class ShareEditDocumentScenario extends AbstractShareScenario
{
    public static final String EVENT_NAME_EDIT_OFFLINE = "share.docDetails.editOffline";

    private String eventNameEditOffline = EVENT_NAME_EDIT_OFFLINE;
    
    /**
     * @param registry              registry with which this instance will be registered
     * @param weight                the weight relative to other scenarios registered in the registry
     */
    public ShareEditDocumentScenario(ShareScenarioRegistry registry, double weight)
    {
        super(registry, weight);
    }

    /**
     * Override the {@link #EVENT_NAME_EDIT_OFFLINE default} event name to edit offline.
     */
    public void setEventNameEditOffline(String eventNameEditOffline)
    {
        this.eventNameEditOffline = eventNameEditOffline;
    }

    /**
     * @see ShareCreateSiteScenario see class comments
     */
    @Override
    public List<Event> getNextEvents(
            Event event,
            ShareEventData eventData,
            ShareSoakData soakData,
            long nextEventTime)
    {
        SharePage sharePage = eventData.getSharePage();
        if (sharePage instanceof DocumentEditOfflinePage)
        {
            // TODO: Do 'Cancel Editing'
            return Collections.emptyList();
        }
        else if (sharePage instanceof DocumentDetailsPage)
        {
            DocumentDetailsPage docDetailsPage = (DocumentDetailsPage) sharePage;
            if (!docDetailsPage.isEditOfflineDisplayed())
            {
                // File is read-only
                return Collections.emptyList();
            }
            // We need to click the 'Edit Offline' link
            ShareEventData nextEventData = new ShareDownloadEventData(eventData, null);
            Event nextEvent = new Event(eventNameEditOffline, nextEventTime, nextEventData);
            return Collections.singletonList(nextEvent);
        }
        else
        {
            // Nothing to 
            return Collections.emptyList();
        }
    }
}
