/*
 * Copyright (C) 2005-2013 Alfresco Software Limited.
 *
 * This file is part of Alfresco
 *
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 */
package org.alfresco.bm.process.share.soak;

import java.util.List;

import org.alfresco.bm.event.Event;
import org.alfresco.bm.process.share.entity.ShareEventData;

/**
 * Share-aware scenario interface.<br/>
 * Implementations choose the next event outcome and ensure the
 * correct input data is available.
 * 
 * @author Derek Hulley
 * @since 1.0
 */
public interface ShareScenario
{
    /**
     * Construct a list of events to follow according to the scenario implementation.
     * <p/>
     * Implementations use the contextual data available to determine the next
     * course of action. However, the <i>no-op</i> (empty list return) should
     * be determined as quickly and cheaply as possible.
     * <p/>
     * <b>NB:
     * Implementations must ensure that an adequate termination condition exists
     * and return an empty list.  If not, an infinite loop of events can ensue.</b>
     * 
     * @param event                 the event that triggered this choice
     * @param eventData             Share-specific data associated with the event
     * @param soakData              Session-specific data for the event
     * @param nextEventTime         the suggested next event time (for guidance)
     * @return                      a list of events to publish (never <tt>null</tt>) or
     *                              an empty list if the scenario cannot continue
     */
    List<Event> getNextEvents(
            Event event,
            ShareEventData eventData,
            ShareSoakData soakData,
            long nextEventTime);
}
