/*
 * Copyright (C) 2005-2014 Alfresco Software Limited.
 *
 * This file is part of Alfresco
 *
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 */
package org.alfresco.bm.process.share.soak;

import com.mongodb.BasicDBObject;
import com.mongodb.DBObject;
/**
 * Session data used to track user soak sessions
 * 
 * @author Derek Hulley
 * @since 1.0
 */
public class ShareSoakData
{
    public static final String KEY_TARGET_SESSION_DURATION = "tsd";
    public static final String KEY_SCENARIO_NAME = "sn";
    
    /**
     * Helper method to convert from JSON to an instance
     */
    public static ShareSoakData fromDBObject(DBObject dbObject)
    {
        ShareSoakData ret = new ShareSoakData();
        Long targetSessionDurationLong = (Long) dbObject.get(KEY_TARGET_SESSION_DURATION);
        if (targetSessionDurationLong != null)
        {
            ret.setTargetSessionDuration(targetSessionDurationLong);
        }
        String scenarioName = (String) dbObject.get(KEY_SCENARIO_NAME);
        if (scenarioName != null)
        {
            ret.setScenarioName(scenarioName);
        }
        return ret;
    }
    
    /**
     * Helper to convert to JSON
     */
    public static DBObject toDBObject(ShareSoakData data)
    {
        DBObject ret = new BasicDBObject()
                .append(KEY_TARGET_SESSION_DURATION, data.getTargetSessionDuration())
                .append(KEY_SCENARIO_NAME, data.getScenarioName());
        return ret;
    }

    private long targetSessionDuration = 0L;
    private String scenarioName = null;
    
    /**
     * Constructor required for persistence
     */
    public ShareSoakData()
    {
    }

    public long getTargetSessionDuration()
    {
        return targetSessionDuration;
    }
    public void setTargetSessionDuration(long targetSessionDuration)
    {
        this.targetSessionDuration = targetSessionDuration;
    }

    public String getScenarioName()
    {
        return scenarioName;
    }
    public void setScenarioName(String scenarioName)
    {
        this.scenarioName = scenarioName;
    }

}
